SystemOrganization addCategory: #ConfigurationOfCountry!

Object subclass: #ConfigurationOfCountry
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfCountry'!

!ConfigurationOfCountry class methodsFor: 'development support' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfCountry class methodsFor: 'private' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfCountry class methodsFor: 'private' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfCountry class methodsFor: 'private' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfCountry class methodsFor: 'metacello tool support' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfCountry class methodsFor: 'loading' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfCountry class methodsFor: 'loading' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfCountry class methodsFor: 'loading' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfCountry class methodsFor: 'accessing' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
project

	^self new project! !

!ConfigurationOfCountry class methodsFor: 'development support' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfCountry methodsFor: 'baselines' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://ss3.gemstone.com/ss/Country'.
		spec project: 'XMLSupport' with: [
				spec
					className: 'ConfigurationOfXMLSupport';
					versionString: #'stable';
					repository: 'http://www.squeaksource.com/XMLSupport' ].
		spec package: 'Country' with: [
				spec requires: #('XMLSupport' ). ].
		spec group: 'default' with: #('Country' ). ].
! !

!ConfigurationOfCountry methodsFor: 'scripts' stamp: 'PaulDeBruicker 2/8/2013 13:26'!
createBaseline
	MetacelloToolBox
		createBaseline: '1.0-baseline'
		for: 'Country'
		repository: 'http://ss3.gemstone.com/ss/Country'
		requiredProjects: #('XMLSupport')
		packages: #('Country')
		dependencies: {('Country' -> #('XMLSupport'))}
		groups: {('default' -> #('Country'))}	"Project name"! !

!ConfigurationOfCountry methodsFor: 'scripts' stamp: 'PaulDeBruicker 2/8/2013 13:27'!
createDevelopmentVersion
	MetacelloToolBox
		createDevelopment: '1.0'
		for: 'Country'
		importFromBaseline: '1.0-baseline'
		description: 'initial development version'! !

!ConfigurationOfCountry methodsFor: 'accessing' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
customProjectAttributes
	 "Edit to return a collection of any custom attributes e.g. for conditional loading: Array with: #'Condition1' with: #'Condition2.
	For more information see: http://code.google.com/p/metacello/wiki/CustomProjectAttrributes"

	^ #().! !

!ConfigurationOfCountry methodsFor: 'symbolic versions' stamp: 'PaulDeBruicker 2/8/2013 13:28'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfCountry methodsFor: 'accessing' stamp: 'PaulDeBruicker 2/8/2013 13:25'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		project := MetacelloMCProject new projectAttributes: self customProjectAttributes. 
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self project: project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfCountry methodsFor: 'scripts' stamp: 'PaulDeBruicker 2/8/2013 13:29'!
vaildateConfiguration
	MetacelloToolBox validateConfiguration: ConfigurationOfCountry! !

!ConfigurationOfCountry methodsFor: 'versions' stamp: 'PaulDeBruicker 2/8/2013 13:28'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'initial development version'.
		spec author: 'PaulDeBruicker'.
		spec timestamp: '2/8/2013 13:28'.
		spec project: 'XMLSupport' with: #'stable'.
		spec package: 'Country' with: 'Country-PaulDeBruicker.1'. ].
! !
